@@ -117,7 +117,7 @@ def parallelized_coherence(args):
             # read auxiliary channel
             try:
                 dt['data'] = dt['data'] - time.time()
-                ch2, fs2 = getRawData(channel2, gpsb, gpse-gpsb,source=opt.source)
+                ch2, fs2 = getRawData(channel2, gpsb, gpse-gpsb)
                 dt['data'] = dt['data'] + time.time()
             except:
                 print("  Process %d: some error occurred in channel %s: %s" % \
